@@ -67,32 +67,30 @@ describe('Dashboard save action', () => {
     // should load chart
     WORLD_HEALTH_CHARTS.forEach(waitForChartLoad);
 
-    // remove box_plot chart from dashboard
+    // remove treemap chart from dashboard
     cy.get('[aria-label="edit-alt"]').click({ timeout: 5000 });
     cy.get('[data-test="dashboard-delete-component-button"]')
       .last()
-      .trigger('moustenter')
+      .trigger('mouseenter')
       .click();
 
-    cy.get('[data-test="grid-container"]')
-      .find('.box_plot')
-      .should('not.exist');
+    cy.get('[data-test="grid-container"]').find('.treemap').should('not.exist');
 
-    cy.intercept('POST', '/superset/save_dash/**/').as('saveRequest');
+    cy.intercept('PUT', '/api/v1/dashboard/**').as('putDashboardRequest');
     cy.get('[data-test="dashboard-header"]')
       .find('[data-test="header-save-button"]')
       .contains('Save')
       .click();
 
     // go back to view mode
-    cy.wait('@saveRequest');
+    cy.wait('@putDashboardRequest');
     cy.get('[data-test="dashboard-header"]')
       .find('[aria-label="edit-alt"]')
       .click();
 
-    // deleted boxplot should still not exist
+    // deleted treemap should still not exist
     cy.get('[data-test="grid-container"]')
-      .find('.box_plot', { timeout: 20000 })
+      .find('.treemap', { timeout: 20000 })
       .should('not.exist');
   });
 
