@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import { List } from 'immutable';
 import JSONbig from 'json-bigint';
 import React, { PureComponent } from 'react';
 import JSONTree from 'react-json-tree';
@@ -128,7 +127,7 @@ export default class FilterableTable extends PureComponent<
     expandedColumns: [],
   };
 
-  list: List<Datum>;
+  list: Datum[];
 
   complexColumns: Record<string, boolean>;
 
@@ -142,7 +141,7 @@ export default class FilterableTable extends PureComponent<
 
   constructor(props: FilterableTableProps) {
     super(props);
-    this.list = List(this.formatTableData(props.data));
+    this.list = this.formatTableData(props.data);
     this.addJsonModal = this.addJsonModal.bind(this);
     this.getCellContent = this.getCellContent.bind(this);
     this.renderGridCell = this.renderGridCell.bind(this);
@@ -182,19 +181,20 @@ export default class FilterableTable extends PureComponent<
     this.fitTableToWidthIfNeeded();
   }
 
-  getDatum(list: List<Datum>, index: number) {
-    return list.get(index % list.size);
+  getDatum(list: Datum[], index: number) {
+    return list[index % list.length];
   }
 
   getWidthsForColumns() {
     const PADDING = 40; // accounts for cell padding and width of sorting icon
     const widthsByColumnKey = {};
-    const cellContent = [].concat(
+    const cellContent = ([] as string[]).concat(
       ...this.props.orderedColumnKeys.map(key => {
         const cellContentList = this.list.map((data: Datum) =>
           this.getCellContent({ cellData: data[key], columnKey: key }),
-        ) as List<string | JSX.Element>;
-        return cellContentList.push(key).toJS();
+        );
+        cellContentList.push(key);
+        return cellContentList;
       }),
     );
 
@@ -210,8 +210,8 @@ export default class FilterableTable extends PureComponent<
       widthsByColumnKey[key] =
         colWidths
           .slice(
-            index * (this.list.size + 1),
-            (index + 1) * (this.list.size + 1),
+            index * (this.list.length + 1),
+            (index + 1) * (this.list.length + 1),
           )
           .reduce((a, b) => Math.max(a, b)) + PADDING;
     });
@@ -225,9 +225,9 @@ export default class FilterableTable extends PureComponent<
   }: {
     cellData: CellDataType;
     columnKey: string;
-  }): string | JSX.Element {
+  }) {
     if (cellData === null) {
-      return <i className="text-muted">NULL</i>;
+      return 'NULL';
     }
     const content = String(cellData);
     const firstCharacter = content.substring(0, 1);
@@ -359,7 +359,12 @@ export default class FilterableTable extends PureComponent<
         ? 'header-style-disabled'
         : 'header-style';
     return (
-      <Tooltip id="header-tooltip" title={label}>
+      <Tooltip
+        id="header-tooltip"
+        title={label}
+        placement="topLeft"
+        css={{ display: 'block' }}
+      >
         <div className={className}>
           {label}
           {sortBy === dataKey && (
@@ -385,7 +390,13 @@ export default class FilterableTable extends PureComponent<
         ? 'header-style-disabled'
         : 'header-style';
     return (
-      <Tooltip key={key} id="header-tooltip" title={label}>
+      <Tooltip
+        key={key}
+        id="header-tooltip"
+        title={label}
+        placement="topLeft"
+        css={{ display: 'block' }}
+      >
         <div
           style={{
             ...style,
@@ -414,8 +425,15 @@ export default class FilterableTable extends PureComponent<
     style: React.CSSProperties;
   }) {
     const columnKey = this.props.orderedColumnKeys[columnIndex];
-    const cellData = this.list.get(rowIndex)[columnKey];
-    const content = this.getCellContent({ cellData, columnKey });
+    const cellData = this.list[rowIndex][columnKey];
+    const content =
+      cellData === null ? (
+        <i className="text-muted">
+          {this.getCellContent({ cellData, columnKey })}
+        </i>
+      ) : (
+        this.getCellContent({ cellData, columnKey })
+      );
     const cellNode = (
       <div
         key={key}
@@ -428,7 +446,7 @@ export default class FilterableTable extends PureComponent<
         }}
         className={`grid-cell ${this.rowClassName({ index: rowIndex })}`}
       >
-        <div>{content}</div>
+        <div css={{ width: 'inherit' }}>{content}</div>
       </div>
     );
 
@@ -493,7 +511,7 @@ export default class FilterableTable extends PureComponent<
                   onScroll={onScroll}
                   overscanColumnCount={overscanColumnCount}
                   overscanRowCount={overscanRowCount}
-                  rowCount={this.list.size}
+                  rowCount={this.list.length}
                   rowHeight={rowHeight}
                   width={this.totalTableWidth}
                 />
@@ -530,18 +548,18 @@ export default class FilterableTable extends PureComponent<
       rowHeight,
     } = this.props;
 
-    let sortedAndFilteredList: List<Datum> = this.list;
+    let sortedAndFilteredList = this.list;
     // filter list
     if (filterText) {
       sortedAndFilteredList = this.list.filter((row: Datum) =>
         this.hasMatch(filterText, row),
-      ) as List<Datum>;
+      );
     }
     // sort list
     if (sortBy) {
       sortedAndFilteredList = sortedAndFilteredList.sort(
         this.sortResults(sortBy, sortDirection === SortDirection.DESC),
-      ) as List<Datum>;
+      );
     }
 
     let { height } = this.props;
@@ -572,7 +590,7 @@ export default class FilterableTable extends PureComponent<
             rowClassName={this.rowClassName}
             rowHeight={rowHeight}
             rowGetter={rowGetter}
-            rowCount={sortedAndFilteredList.size}
+            rowCount={sortedAndFilteredList.length}
             sort={this.sort}
             sortBy={sortBy}
             sortDirection={sortDirection}
