@@ -17,6 +17,7 @@
 # under the License.
 import json
 import logging
+import os
 import sys
 from datetime import datetime, timedelta
 from pathlib import Path
@@ -26,11 +27,14 @@ from zipfile import is_zipfile, ZipFile
 
 import click
 import yaml
+from apispec import APISpec
+from apispec.ext.marshmallow import MarshmallowPlugin
 from celery.utils.abstract import CallableTask
 from colorama import Fore, Style
 from flask import current_app, g
 from flask.cli import FlaskGroup, with_appcontext
 from flask_appbuilder import Model
+from flask_appbuilder.api import BaseApi
 
 from superset import app, appbuilder, config, security_manager
 from superset.app import create_app
@@ -78,7 +82,7 @@ def superset() -> None:
     """This is a management script for the Superset application."""
 
     @app.shell_context_processor
-    def make_shell_context() -> Dict[str, Any]:  # pylint: disable=unused-variable
+    def make_shell_context() -> Dict[str, Any]:
         return dict(app=app, db=db)
 
 
@@ -120,6 +124,7 @@ def load_examples_run(
         examples_db = utils.get_example_database()
         print(f"Loading examples metadata and related data into {examples_db}")
 
+    # pylint: disable=import-outside-toplevel
     from superset import examples
 
     examples.load_css_templates()
@@ -168,7 +173,7 @@ def load_examples_run(
         examples.load_big_data()
 
     # load examples that are stored as YAML config files
-    examples.load_from_configs(force, load_test_data)
+    examples.load_examples_from_configs(force, load_test_data)
 
 
 @with_appcontext
@@ -176,10 +181,10 @@ def load_examples_run(
 @click.option("--load-test-data", "-t", is_flag=True, help="Load additional test data")
 @click.option("--load-big-data", "-b", is_flag=True, help="Load additional big data")
 @click.option(
-    "--only-metadata", "-m", is_flag=True, help="Only load metadata, skip actual data"
+    "--only-metadata", "-m", is_flag=True, help="Only load metadata, skip actual data",
 )
 @click.option(
-    "--force", "-f", is_flag=True, help="Force load data even if table already exists"
+    "--force", "-f", is_flag=True, help="Force load data even if table already exists",
 )
 def load_examples(
     load_test_data: bool,
@@ -187,10 +192,29 @@ def load_examples(
     only_metadata: bool = False,
     force: bool = False,
 ) -> None:
-    """Loads a set of Slices and Dashboards and a supporting dataset """
+    """Loads a set of Slices and Dashboards and a supporting dataset"""
     load_examples_run(load_test_data, load_big_data, only_metadata, force)
 
 
+@with_appcontext
+@superset.command()
+@click.argument("directory")
+@click.option(
+    "--overwrite", "-o", is_flag=True, help="Overwriting existing metadata definitions",
+)
+@click.option(
+    "--force", "-f", is_flag=True, help="Force load data even if table already exists",
+)
+def import_directory(directory: str, overwrite: bool, force: bool) -> None:
+    """Imports configs from a given directory"""
+    # pylint: disable=import-outside-toplevel
+    from superset.examples.utils import load_configs_from_directory
+
+    load_configs_from_directory(
+        root=Path(directory), overwrite=overwrite, force_data=force,
+    )
+
+
 @with_appcontext
 @superset.command()
 @click.option("--database_name", "-d", help="Database name to change")
@@ -203,7 +227,7 @@ def load_examples(
     help="Create the DB if it doesn't exist",
 )
 def set_database_uri(database_name: str, uri: str, skip_create: bool) -> None:
-    """Updates a database connection URI """
+    """Updates a database connection URI"""
     utils.get_or_create_db(database_name, uri, not skip_create)
 
 
@@ -224,9 +248,11 @@ def set_database_uri(database_name: str, uri: str, skip_create: bool) -> None:
 )
 def refresh_druid(datasource: str, merge: bool) -> None:
     """Refresh druid datasources"""
-    session = db.session()
+    # pylint: disable=import-outside-toplevel
     from superset.connectors.druid.models import DruidCluster
 
+    session = db.session()
+
     for cluster in session.query(DruidCluster).all():
         try:
             cluster.refresh_datasources(datasource_name=datasource, merge_flag=merge)
@@ -247,6 +273,7 @@ if feature_flags.get("VERSIONED_EXPORT"):
     )
     def export_dashboards(dashboard_file: Optional[str] = None) -> None:
         """Export dashboards to ZIP file"""
+        # pylint: disable=import-outside-toplevel
         from superset.dashboards.commands.export import ExportDashboardsCommand
         from superset.models.dashboard import Dashboard
 
@@ -269,8 +296,8 @@ if feature_flags.get("VERSIONED_EXPORT"):
                 "There was an error when exporting the dashboards, please check "
                 "the exception traceback in the log"
             )
+            sys.exit(1)
 
-    # pylint: disable=too-many-locals
     @superset.command()
     @with_appcontext
     @click.option(
@@ -278,6 +305,7 @@ if feature_flags.get("VERSIONED_EXPORT"):
     )
     def export_datasources(datasource_file: Optional[str] = None) -> None:
         """Export datasources to ZIP file"""
+        # pylint: disable=import-outside-toplevel
         from superset.connectors.sqla.models import SqlaTable
         from superset.datasets.commands.export import ExportDatasetsCommand
 
@@ -298,6 +326,7 @@ if feature_flags.get("VERSIONED_EXPORT"):
                 "There was an error when exporting the datasets, please check "
                 "the exception traceback in the log"
             )
+            sys.exit(1)
 
     @superset.command()
     @with_appcontext
@@ -312,6 +341,7 @@ if feature_flags.get("VERSIONED_EXPORT"):
     )
     def import_dashboards(path: str, username: Optional[str]) -> None:
         """Import dashboards from ZIP file"""
+        # pylint: disable=import-outside-toplevel
         from superset.commands.importers.v1.utils import get_contents_from_bundle
         from superset.dashboards.commands.importers.dispatcher import (
             ImportDashboardsCommand,
@@ -323,7 +353,8 @@ if feature_flags.get("VERSIONED_EXPORT"):
             with ZipFile(path) as bundle:
                 contents = get_contents_from_bundle(bundle)
         else:
-            contents = {path: open(path).read()}
+            with open(path) as file:
+                contents = {path: file.read()}
         try:
             ImportDashboardsCommand(contents, overwrite=True).run()
         except Exception:  # pylint: disable=broad-except
@@ -331,6 +362,7 @@ if feature_flags.get("VERSIONED_EXPORT"):
                 "There was an error when importing the dashboards(s), please check "
                 "the exception traceback in the log"
             )
+            sys.exit(1)
 
     @superset.command()
     @with_appcontext
@@ -339,6 +371,7 @@ if feature_flags.get("VERSIONED_EXPORT"):
     )
     def import_datasources(path: str) -> None:
         """Import datasources from ZIP file"""
+        # pylint: disable=import-outside-toplevel
         from superset.commands.importers.v1.utils import get_contents_from_bundle
         from superset.datasets.commands.importers.dispatcher import (
             ImportDatasetsCommand,
@@ -348,7 +381,8 @@ if feature_flags.get("VERSIONED_EXPORT"):
             with ZipFile(path) as bundle:
                 contents = get_contents_from_bundle(bundle)
         else:
-            contents = {path: open(path).read()}
+            with open(path) as file:
+                contents = {path: file.read()}
         try:
             ImportDatasetsCommand(contents, overwrite=True).run()
         except Exception:  # pylint: disable=broad-except
@@ -356,6 +390,7 @@ if feature_flags.get("VERSIONED_EXPORT"):
                 "There was an error when importing the dataset(s), please check the "
                 "exception traceback in the log"
             )
+            sys.exit(1)
 
 
 else:
@@ -363,7 +398,10 @@ else:
     @superset.command()
     @with_appcontext
     @click.option(
-        "--dashboard-file", "-f", default=None, help="Specify the the file to export to"
+        "--dashboard-file",
+        "-f",
+        default=None,
+        help="Specify the the file to export to",
     )
     @click.option(
         "--print_stdout",
@@ -376,6 +414,7 @@ else:
         dashboard_file: Optional[str], print_stdout: bool = False
     ) -> None:
         """Export dashboards to JSON"""
+        # pylint: disable=import-outside-toplevel
         from superset.utils import dashboard_import_export
 
         data = dashboard_import_export.export_dashboards(db.session)
@@ -386,7 +425,6 @@ else:
             with open(dashboard_file, "w") as data_stream:
                 data_stream.write(data)
 
-    # pylint: disable=too-many-locals
     @superset.command()
     @with_appcontext
     @click.option(
@@ -423,6 +461,7 @@ else:
         include_defaults: bool = False,
     ) -> None:
         """Export datasources to YAML"""
+        # pylint: disable=import-outside-toplevel
         from superset.utils import dict_import_export
 
         data = dict_import_export.export_to_dict(
@@ -461,6 +500,7 @@ else:
     )
     def import_dashboards(path: str, recursive: bool, username: str) -> None:
         """Import dashboards from JSON file"""
+        # pylint: disable=import-outside-toplevel
         from superset.dashboards.commands.importers.v0 import ImportDashboardsCommand
 
         path_object = Path(path)
@@ -473,11 +513,15 @@ else:
             files.extend(path_object.rglob("*.json"))
         if username is not None:
             g.user = security_manager.find_user(username=username)
-        contents = {path.name: open(path).read() for path in files}
+        contents = {}
+        for path_ in files:
+            with open(path_) as file:
+                contents[path_.name] = file.read()
         try:
             ImportDashboardsCommand(contents).run()
         except Exception:  # pylint: disable=broad-except
             logger.exception("Error when importing dashboard")
+            sys.exit(1)
 
     @superset.command()
     @with_appcontext
@@ -505,6 +549,7 @@ else:
     )
     def import_datasources(path: str, sync: str, recursive: bool) -> None:
         """Import datasources from YAML"""
+        # pylint: disable=import-outside-toplevel
         from superset.datasets.commands.importers.v0 import ImportDatasetsCommand
 
         sync_array = sync.split(",")
@@ -521,11 +566,15 @@ else:
         elif path_object.exists() and recursive:
             files.extend(path_object.rglob("*.yaml"))
             files.extend(path_object.rglob("*.yml"))
-        contents = {path.name: open(path).read() for path in files}
+        contents = {}
+        for path_ in files:
+            with open(path_) as file:
+                contents[path_.name] = file.read()
         try:
             ImportDatasetsCommand(contents, sync_columns, sync_metrics).run()
         except Exception:  # pylint: disable=broad-except
             logger.exception("Error when importing dataset")
+            sys.exit(1)
 
     @superset.command()
     @with_appcontext
@@ -538,6 +587,7 @@ else:
     )
     def export_datasource_schema(back_references: bool) -> None:
         """Export datasource YAML schema to stdout"""
+        # pylint: disable=import-outside-toplevel
         from superset.utils import dict_import_export
 
         data = dict_import_export.export_schema_to_dict(back_references=back_references)
@@ -548,6 +598,7 @@ else:
 @with_appcontext
 def update_datasources_cache() -> None:
     """Refresh sqllab datasources cache"""
+    # pylint: disable=import-outside-toplevel
     from superset.models.core import Database
 
     for database in db.session.query(Database).all():
@@ -567,7 +618,7 @@ def update_datasources_cache() -> None:
 @superset.command()
 @with_appcontext
 @click.option(
-    "--workers", "-w", type=int, help="Number of celery server workers to fire up"
+    "--workers", "-w", type=int, help="Number of celery server workers to fire up",
 )
 def worker(workers: int) -> None:
     """Starts a Superset worker for async SQL query execution."""
@@ -589,10 +640,10 @@ def worker(workers: int) -> None:
 @superset.command()
 @with_appcontext
 @click.option(
-    "-p", "--port", default="5555", help="Port on which to start the Flower process"
+    "-p", "--port", default="5555", help="Port on which to start the Flower process",
 )
 @click.option(
-    "-a", "--address", default="localhost", help="Address on which to run the service"
+    "-a", "--address", default="localhost", help="Address on which to run the service",
 )
 def flower(port: int, address: str) -> None:
     """Runs a Celery Flower web server
@@ -614,7 +665,7 @@ def flower(port: int, address: str) -> None:
     print(Fore.BLUE + "-=" * 40)
     print(Fore.YELLOW + cmd)
     print(Fore.BLUE + "-=" * 40)
-    Popen(cmd, shell=True).wait()
+    Popen(cmd, shell=True).wait()  # pylint: disable=consider-using-with
 
 
 @superset.command()
@@ -634,7 +685,7 @@ def flower(port: int, address: str) -> None:
     help="Only process dashboards",
 )
 @click.option(
-    "--charts_only", "-c", is_flag=True, default=False, help="Only process charts"
+    "--charts_only", "-c", is_flag=True, default=False, help="Only process charts",
 )
 @click.option(
     "--force",
@@ -652,6 +703,7 @@ def compute_thumbnails(
     model_id: int,
 ) -> None:
     """Compute thumbnails"""
+    # pylint: disable=import-outside-toplevel
     from superset.models.dashboard import Dashboard
     from superset.models.slice import Slice
     from superset.tasks.thumbnails import (
@@ -764,6 +816,7 @@ def sync_tags() -> None:
     # pylint: disable=no-member
     metadata = Model.metadata
 
+    # pylint: disable=import-outside-toplevel
     from superset.common.tags import add_favorites, add_owners, add_types
 
     add_types(db.engine, metadata)
@@ -776,6 +829,7 @@ def sync_tags() -> None:
 def alert() -> None:
     """Run the alert scheduler loop"""
     # this command is just for testing purposes
+    # pylint: disable=import-outside-toplevel
     from superset.models.schedules import ScheduleType
     from superset.tasks.schedules import schedule_window
 
@@ -794,13 +848,8 @@ def alert() -> None:
 @with_appcontext
 def update_api_docs() -> None:
     """Regenerate the openapi.json file in docs"""
-    from apispec import APISpec
-    from apispec.ext.marshmallow import MarshmallowPlugin
-    from flask_appbuilder.api import BaseApi
-    from os import path
-
-    superset_dir = path.abspath(path.dirname(__file__))
-    openapi_json = path.join(
+    superset_dir = os.path.abspath(os.path.dirname(__file__))
+    openapi_json = os.path.join(
         superset_dir, "..", "docs", "src", "resources", "openapi.json"
     )
     api_version = "v1"
