@@ -17,7 +17,7 @@
 import json
 
 import pandas as pd
-from sqlalchemy import BigInteger, Float, Text
+from sqlalchemy import BigInteger, Float, inspect, Text
 
 from superset import db
 from superset.utils import core as utils
@@ -28,8 +28,10 @@ from .helpers import get_example_data, get_table_connector_registry
 def load_sf_population_polygons(
     only_metadata: bool = False, force: bool = False
 ) -> None:
-    tbl_name = "San Francisco Population Polygons"
+    tbl_name = "sf_population_polygons"
     database = utils.get_example_database()
+    engine = database.get_sqla_engine()
+    schema = inspect(engine).default_schema_name
     table_exists = database.has_table_by_name(tbl_name)
 
     if not only_metadata and (not table_exists or force):
@@ -39,7 +41,8 @@ def load_sf_population_polygons(
 
         df.to_sql(
             tbl_name,
-            database.get_sqla_engine(),
+            engine,
+            schema=schema,
             if_exists="replace",
             chunksize=500,
             dtype={
@@ -55,7 +58,7 @@ def load_sf_population_polygons(
     table = get_table_connector_registry()
     tbl = db.session.query(table).filter_by(table_name=tbl_name).first()
     if not tbl:
-        tbl = table(table_name=tbl_name)
+        tbl = table(table_name=tbl_name, schema=schema)
     tbl.description = "Population density of San Francisco"
     tbl.database = database
     tbl.filter_select_enabled = True
